@@ -15,29 +15,28 @@ sub match {
     my $argv1 = shift // return 0;
 
     state $index = [
-        'as a relay',
-        'email address is not verified.',
-        'insecure mail relay',
-        'is not permitted to relay through this server without authentication',
-        'mail server requires authentication when attempting to send to a non-local e-mail address',    # MailEnable
-        'no relaying',
-        'not a gateway',
-        'not allowed to relay through this machine',
-        'not an open relay, so get lost',
-        'not local host',
-        'relay access denied',
-        'relay denied',
-        'relaying mail to ',
-        'relay not permitted',
-        'relaying denied',  # Sendmail
-        'relaying mail to ',
-        'specified domain is not allowed',
-        "that domain isn't in my list of allowed rcpthost",
-        'this system is not configured to relay mail',
-        'unable to relay ',
+        "as a relay",
+        "domain isn't in my list of allowed rcpthost",
+        "email address is not verified.",
+        "insecure mail relay",
+        "no relaying",
+        "not a gateway",
+        "not an open relay, so get lost",
+        "not local host",
+        "relay not permitted",
+        "relaying denied", # Sendmail
+        "relaying mail to ",
+        "send to a non-local e-mail address", # MailEnable
+        "specified domain is not allowed",
+        "unable to relay ",
         "we don't handle mail for",
     ];
+    state $pairs = [
+        ["relay ", "denied"],
+        [" not ", " to relay"],
+    ];
     return 1 if grep { rindex($argv1, $_) > -1 } @$index;
+    return 1 if grep { Sisimai::String->aligned(\$argv1, $_) } @$pairs;
     return 0;
 }
 
@@ -110,7 +109,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2018,2020-2025 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2018,2020-2026 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
