@@ -14,7 +14,7 @@ sub find {
     # @see      https://technet.microsoft.com/en-us/library/bb232118
     # @since v4.17.2
     my $class = shift;
-    my $argvs = shift // return undef;
+    my $argvs = shift // return "";
     return '' unless $argvs->{'deliverystatus'};
     return '' unless Sisimai::SMTP::Status->test($argvs->{'deliverystatus'});
 
@@ -32,6 +32,13 @@ sub find {
             # - Access denied, sending domain [$SenderDomain] does not pass DMARC verification
             # - The sender's domain in the 5322.From address doesn't pass DMARC.
             ['5.7.509', 0, 0, 'does not pass dmarc verification'],
+
+            # - 550 5.7.515 Access denied, sending domain EXAMPLE.JP doesn't meet the required
+            #   authentication level. The sender's domain in the 5322.From address doesn't meet
+            #   the authentication requirements defined for the sender. To learn how to fix this
+            #   see: https://go.microsoft.com/fwlink/p/?linkid=2319303
+            #   Spf= Fail , Dkim= Pass , DMARC= Pass ...
+            ["5.7.515", 0, 0, "doesn't meet the required authentication level"],
         ],
         'badreputation' => [
             # Undocumented error messages ---------------------------------------------------------
@@ -133,12 +140,21 @@ sub find {
             ['5.4.11', 0, 0, 'agent generated message depth exceeded'],
             ['5.5.6',  0, 0, 'invalid message content'],
         ],
-        'exceedlimit' => [
+        'emailtoolarge' => [
             # Exchange Server 2019 ----------------------------------------------------------------
             # - The message is too large. Send the message again without any attachments, or confi-
             #   gure a larger message size limit for the recipient. For more information, see Re-
             #   cipient limits.
             ['5.2.3', 0, 0, 'resolver.rst.recipsizelimit; message too large for this recipient'],
+
+            # - The message is too large. This error can be generated by the source or destination
+            #   messaging system. Send the message again without any attachments, or configure a
+            #   larger message size limit. For more information, see Message size and recipient
+            #   limits in Exchange Server.
+            ['5.3.4', 0, 0, 'message size exceeds fixed maximum message size'],
+
+            # Previous versions of Exchange Server ------------------------------------------------
+            ['5.3.4', 0, 0, 'message too big for system'],
         ],
         'expired' => [
             # Exchange Server 2019 ----------------------------------------------------------------
@@ -219,9 +235,9 @@ sub find {
             # - A valid X.509 certificate that isn't expired must be presented. X.509 certificates
             #   must be renewed after their expiration, commonly annually.
             ['5.7.51',  0, 0, 'restrictdomainstoipaddresses or restrictdomainstocertificate'],
-            ['4.7.321', 0, 0, 'starttls-not-supported: destination mail server must support tls to receive mail'],
-            ['5.7.321', 0, 0, 'starttls-not-supported: destination mail server must support tls to receive mail'],
-            ['5.7.322', 0, 0, "certificate-expired: destination mail server's certificate is expired"],
+            ['4.7.321', 0, 0, 'starttls-not-supported:'],
+            ['5.7.321', 0, 0, 'starttls-not-supported:'],
+            ['5.7.322', 0, 0, "certificate-expired:"],
 
             # - Records are DNSSEC authentic, but one or multiple of these scenarios occurred:
             #   - The destination mail server's certificate doesn't match with what is expected per
@@ -233,13 +249,13 @@ sub find {
             #   validity of recipient address and determine if the destination server is configured
             #   correctly to receive messages. 
             # - For more information about DANE, see: https://datatracker.ietf.org/doc/html/rfc7671
-            ['4.7.323', 0, 0, 'tlsa-invalid: The domain failed dane validation'],
-            ['5.7.323', 0, 0, 'tlsa-invalid: The domain failed dane validation'],
+            ['4.7.323', 0, 0, 'tlsa-invalid:'],
+            ['5.7.323', 0, 0, 'tlsa-invalid:'],
 
             # - The destination domain indicated it was DNSSEC-authentic, but Exchange Online was 
             #   not able to verify it as DNSSEC-authentic.
-            ['4.7.324', 0, 0, 'dnssec-invalid: destination domain returned invalid dnssec records'],
-            ['5.7.324', 0, 0, 'dnssec-invalid: destination domain returned invalid dnssec records'],
+            ['4.7.324', 0, 0, 'dnssec-invalid:'],
+            ['5.7.324', 0, 0, 'dnssec-invalid:'],
 
             # - This happens when the presented certificate identities (CN and SAN) of a destina-
             #   tion SMTP target host don't match any of the domains or MX host.
@@ -247,8 +263,8 @@ sub find {
             #   validity of recipient address and determine if the destination server is configured
             #   correctly to receive messages. For more information, see How SMTP DNS-based Authen-
             #   tication of Named Entities (DANE) works to secure email communications.
-            ['4.7.325', 0, 0, 'certificate-host-mismatch: remote certificate must have a common name or subject alternative name matching the hostname (dane)'],
-            ['5.7.325', 0, 0, 'certificate-host-mismatch: remote certificate must have a common name or subject alternative name matching the hostname (dane)'],
+            ['4.7.325', 0, 0, 'certificate-host-mismatch:'],
+            ['5.7.325', 0, 0, 'certificate-host-mismatch:'],
         ],
         'mailboxfull' => [
             # Exchange Server 2019 ----------------------------------------------------------------
@@ -257,17 +273,6 @@ sub find {
             #   figure storage quotas for a mailbox.
             ['5.2.2', 0, 0, 'mailbox full'],
         ],
-        'mesgtoobig' => [
-            # Exchange Server 2019 ----------------------------------------------------------------
-            # - The message is too large. This error can be generated by the source or destination
-            #   messaging system. Send the message again without any attachments, or configure a
-            #   larger message size limit. For more information, see Message size and recipient
-            #   limits in Exchange Server.
-            ['5.3.4', 0, 0, 'message size exceeds fixed maximum message size'],
-
-            # Previous versions of Exchange Server ------------------------------------------------
-            ['5.3.4', 0, 0, 'message too big for system'],
-        ],
         'networkerror' => [
             # Exchange Server 2019 ----------------------------------------------------------------
             # - There's a DNS or network adapter configuration issue on the Exchange server. Verify
@@ -391,6 +396,78 @@ sub find {
             #   Mail flow rule actions in Exchange Server.
             ['5.7.', 900, 999, 'delivery not authorized, message refused'],
         ],
+        'ratelimited' => [
+            # Exchange Server 2019 ----------------------------------------------------------------
+            # - The combined total of recipients on the To, Cc, and Bcc lines of the message ex-
+            #   ceeds the total number of recipients allowed in a single message for the organiza-
+            #   tion, Receive connector, or sender. For more information, see Message size and re-
+            #   cipient limits in Exchange Server.
+            ['5.5.3', 0, 0, 'too many recipients'],
+            
+            # Exchange Online ---------------------------------------------------------------------
+            # - The recipient mailbox's ability to accept messages is being throttled because it's
+            #   receiving too many messages too quickly. This is done so a single recipient's mail
+            #   processing doesn't unfairly impact other recipients sharing the same mailbox data-
+            #   base.
+            ['4.3.2', 0, 0, 'storedrv.deliver; recipient thread limit exceeded'],
+
+            # - The message has more than 200 SMTP envelope recipients from the same domain.
+            # - An envelope recipient is the original, unexpanded recipient that's used in the RCPT
+            #   TO command to transmit the message between SMTP servers. When this error is return-
+            #   ed by Microsoft 365 or Office 365, the sending server must break up the number of
+            #   envelope recipients into smaller chunks (chunking) and resend the message.
+            ['4.5.3', 0, 0, 'too many recipients'],
+
+            # - The sender has exceeded the recipient rate limit as described in Sending limits.
+            # - This could indicate the account has been compromised and is being used to send
+            #   spam.
+            ['5.1.90', 0, 0, "reached your daily limit for message recipients"],
+
+            # - The sender has exceeded the recipient rate limit or the message rate limit as de-
+            #   scribed in Sending limits.
+            # - This could indicate the account has been compromised and is being used to send
+            #   spam.
+            ['5.2.2', 0, 0, 'submission quota exceeded'],
+
+            # - The sender has exceeded the maximum number of messages they're allowed to send per
+            #   hour to a specific recipient in Exchange Online.
+            # - The automated mailer or sender should try again later, and reduce the number of
+            #   messages they send per hour to a specific recipient. This limit helps protect
+            #   Microsoft 365 or Office 365 users from rapidly filling their inboxes with a large
+            #   number of messages from errant automated notification systems or other single-send-
+            #   er mail storms.
+            ['5.2.121', 0, 0, "recipient's per hour message receive limit"],
+
+            # - The Microsoft 365 or Office 365 recipient has exceeded the number of messages they
+            #   can receive per hour from all senders.
+            # - The automated mailer or sender should try again later, and reduce the number of
+            #   messages they send per hour to a specific recipient. This limit helps protect
+            #   Microsoft 365 and Office 365 users from rapidly filling their inboxes with a large
+            #   number of messages from errant automated notification systems or other mail storms.
+            ['5.2.122', 0, 0, "recipient's per hour message receive limit"],
+
+            # - Access denied, [$SenderIPAddress] has exceeded permitted limits within $range range
+            # - The sender's IPv6 range has attempted to send too many messages in too short a time
+            #   period.
+            ['5.7.508', 0, 0, 'has exceeded permitted limits within'],
+
+            # - The majority of traffic from this tenant has been detected as suspicious and has
+            #   resulted in a ban on sending ability for the tenant.
+            # - Ensure that any compromises or open relays have been resolved, and then contact
+            #   support through your regular channel. For more information, see Fix email delivery
+            #   issues for error codes 5.7.700 through 5.7.750 in Exchange Online.
+            ['5.7.', 700, 749, 'tenant has exceeded threshold'],
+            ['5.7.', 700, 749, 'traffic not accepted from this ip'],
+
+            # - 451 4.7.652 The mail server [192.0.2.251] has exceeded the maximum number of
+            #   connections. (S3115) [Name=Protocol Filter Agent][AGT=PFA][MxId=11BA9B3FA168ABBF]
+            #   [BN3PEPF0000B370.namprd21.prod.outlook.com 2025-02-20T14:30:32.425Z 08DD4D9FD5AFF45C]
+            #   (in reply to MAIL FROM command))
+            ["4.7.652", 0, 0, "has exceeded the maximum number of connections"],
+
+            # Previous versions of Exchange Server ------------------------------------------------
+            ['5.2.122', 0, 0, 'the recipient has exceeded their limit for'],
+        ],
         'rejected' => [
             # Exchange Server 2019 ----------------------------------------------------------------
             # - There's a problem with the sender's email address. Verify the sender's email ad-
@@ -509,55 +586,6 @@ sub find {
             #   sender exceptions for content filtering.
             ['5.2.1', 0, 0, 'content filter agent quarantined this message'],
         ],
-        'speeding' => [
-            # Exchange Online ---------------------------------------------------------------------
-            # - The recipient mailbox's ability to accept messages is being throttled because it's
-            #   receiving too many messages too quickly. This is done so a single recipient's mail
-            #   processing doesn't unfairly impact other recipients sharing the same mailbox data-
-            #   base.
-            ['4.3.2', 0, 0, 'storedrv.deliver; recipient thread limit exceeded'],
-
-            # - The sender has exceeded the recipient rate limit as described in Sending limits.
-            # - This could indicate the account has been compromised and is being used to send
-            #   spam.
-            ['5.1.90', 0, 0, "your message can't be sent because you've reached your daily limit for message recipients"],
-
-            # - The sender has exceeded the recipient rate limit or the message rate limit as de-
-            #   scribed in Sending limits.
-            # - This could indicate the account has been compromised and is being used to send
-            #   spam.
-            ['5.2.2', 0, 0, 'submission quota exceeded'],
-
-            # - The sender has exceeded the maximum number of messages they're allowed to send per
-            #   hour to a specific recipient in Exchange Online.
-            # - The automated mailer or sender should try again later, and reduce the number of
-            #   messages they send per hour to a specific recipient. This limit helps protect
-            #   Microsoft 365 or Office 365 users from rapidly filling their inboxes with a large
-            #   number of messages from errant automated notification systems or other single-send-
-            #   er mail storms.
-            ['5.2.121', 0, 0, "recipient's per hour message receive limit from specific sender exceeded"],
-
-            # - The Microsoft 365 or Office 365 recipient has exceeded the number of messages they
-            #   can receive per hour from all senders.
-            # - The automated mailer or sender should try again later, and reduce the number of
-            #   messages they send per hour to a specific recipient. This limit helps protect
-            #   Microsoft 365 and Office 365 users from rapidly filling their inboxes with a large
-            #   number of messages from errant automated notification systems or other mail storms.
-            ['5.2.122', 0, 0, "recipient's per hour message receive limit exceeded"],
-
-            # - Access denied, [$SenderIPAddress] has exceeded permitted limits within $range range
-            # - The sender's IPv6 range has attempted to send too many messages in too short a time
-            #   period.
-            ['5.7.508', 0, 0, 'has exceeded permitted limits within'],
-
-            # - The majority of traffic from this tenant has been detected as suspicious and has
-            #   resulted in a ban on sending ability for the tenant.
-            # - Ensure that any compromises or open relays have been resolved, and then contact
-            #   support through your regular channel. For more information, see Fix email delivery
-            #   issues for error codes 5.7.700 through 5.7.750 in Exchange Online.
-            ['5.7.', 700, 749, 'access denied, tenant has exceeded threshold'],
-            ['5.7.', 700, 749, 'access denied, traffic not accepted from this ip'],
-        ],
         'suspend' => [
             # Exchange Online ---------------------------------------------------------------------
             # - The recipient address that you're attempting to contact isn't valid.
@@ -614,7 +642,7 @@ sub find {
             #   is disabled. For this scenario to work, the organization's Office 365 administrator
             #   should either enable Journaling Archive or change the journaling rule to journal
             #   messages to a different location.
-            ['5.3.190', 0, 0, 'journaling on-premises messages to microsoft 365 or office 365 not supported when journaling archive is disabled'],
+            ['5.3.190', 0, 0, 'when journaling archive is disabled'],
 
             # Previous versions of Exchange Server ------------------------------------------------
             ['5.0.0',  0, 0, 'helo / ehlo requires domain address'],
@@ -623,11 +651,16 @@ sub find {
             ['5.2.14', 0, 0, 'misconfigured forwarding address'],
 
             # Undocumented error messages ---------------------------------------------------------
-            ['4.4.3',  0, 0, 'temporary server error. please try again later attr18'],
-            ['4.7.0',  0, 0, 'temporary server error. please try again later. prx4 nexthop:'],
-            ['4.4.24', 0, 0, 'message failed to be replicated: insufficient system resource:'],
-            ['4.4.25', 0, 0, 'message failed to be replicated: no healthy secondary server available to accept replica at this time.'],
-            ['4.4.28', 0, 0, 'message failed to be replicated: the operation was canceled'],
+            # - 451 4.4.22 Message failed to be replicated: no healthy peers found ... (in reply to end of DATA command)
+            # - 451 4.4.23 Message failed to be replicated: No healthy secondary server available
+            #   to accept replica at this time. ... (in reply to end of DATA command)
+            # - 451 4.4.28 Message failed to be replicated:
+            #   Microsoft.Exchange.Transport.Net.Http.TransportHttpException(session Id: -1) ...(in reply to end of DATA command)
+            # - 451 4.4.28 Message failed to be replicated:
+            #   System.Net.Http.HttpRequestException(session Id: ****) ... (in reply to end of DATA command)
+            ["4.4.",  22, 28, "message failed to be replicated:"],
+            ["4.4.3",  0,  0, "temporary server error. please try again later attr18"],
+            ["4.7.0",  0,  0, "temporary server error. please try again later. prx4 nexthop:"],
 
             # 550 5.4.318 Message expired, connection reset (SuspiciousRemoteServerError)
             # 450 4.4.318 Connection was closed abruptly (SuspiciousRemoteServerError)
@@ -655,31 +688,6 @@ sub find {
             #   machines.
             ['4.3.1', 0, 0, 'insufficient system resources'],
         ],
-        'toomanyconn' => [
-            # Exchange Server 2019 ----------------------------------------------------------------
-            # - The combined total of recipients on the To, Cc, and Bcc lines of the message ex-
-            #   ceeds the total number of recipients allowed in a single message for the organiza-
-            #   tion, Receive connector, or sender. For more information, see Message size and re-
-            #   cipient limits in Exchange Server.
-            ['5.5.3', 0, 0, 'too many recipients'],
-            
-            # Exchange Online ---------------------------------------------------------------------
-            # - The message has more than 200 SMTP envelope recipients from the same domain.
-            # - An envelope recipient is the original, unexpanded recipient that's used in the RCPT
-            #   TO command to transmit the message between SMTP servers. When this error is return-
-            #   ed by Microsoft 365 or Office 365, the sending server must break up the number of
-            #   envelope recipients into smaller chunks (chunking) and resend the message.
-            ['4.5.3', 0, 0, 'too many recipients'],
-
-            # - 451 4.7.652 The mail server [192.0.2.251] has exceeded the maximum number of
-            #   connections. (S3115) [Name=Protocol Filter Agent][AGT=PFA][MxId=11BA9B3FA168ABBF]
-            #   [BN3PEPF0000B370.namprd21.prod.outlook.com 2025-02-20T14:30:32.425Z 08DD4D9FD5AFF45C]
-            #   (in reply to MAIL FROM command))
-            ["4.7.652", 0, 0, "has exceeded the maximum number of connections"],
-
-            # Previous versions of Exchange Server ------------------------------------------------
-            ['5.2.122', 0, 0, 'the recipient has exceeded their limit for'],
-        ],
         'userunknown' => [
             # Exchange Server 2019 ----------------------------------------------------------------
             # - The recipient's email address is incorrect (the recipient doesn't exist in the des-
@@ -745,13 +753,61 @@ sub find {
             ['5.1.351', 0, 0, 'remote server returned unknown recipient or mailbox unavailable'],
         ],
     };
+    state $errorcodes = {
+        #  The mail server IP connecting to Outlook.com server has exceeded the rate limit allowed.
+        #  Reason for rate limitation is related to IP/domain reputation.
+        "RP-001" => ["421", "badreputation"],
+
+        #  The mail server IP connecting to Outlook.com server has exceeded the rate limit allowed
+        #  on this connection. Reason for rate limitation is related to IP/domain reputation.
+        "RP-002" => ["421", "badreputation"],
+
+        #  The mail server IP connecting to Outlook.com server has exceeded the connection limit
+        #  allowed. Reason for limitation is related to IP/domain reputation.
+        "RP-003" => ["421", "badreputation"],
+
+        #  Mail rejected by Outlook.com for policy reasons. Reasons for rejection may be related
+        #  to content with spam-like characteristics or IP/domain reputation. 
+        "SC-001" => ["550", "badreputation"],
+
+        #  Mail rejected by Outlook.com for policy reasons. The mail server IP connecting to
+        #  Outlook.com has exhibited namespace mining behavior.
+        "SC-002" => ["550", "policyviolation"],
+
+        #  Mail rejected by Outlook.com for policy reasons. Your IP address appears to be an
+        #  open proxy/relay.
+        "SC-003" => ["550", "blocked"],
+
+        #  Mail rejected by Outlook.com for policy reasons. A block has been placed against your
+        #  IP address because we have received complaints concerning mail coming from that IP
+        #  address. We recommend enrolling in our Junk Email Reporting Program (JMRP), a free
+        #  program intended to help senders remove unwanted recipients from their email list
+        "SC-004" => ["550", "blocked"],
+
+        #  Mail rejected by Outlook.com for policy reasons. We generally do not accept email
+        #  from dynamic IP's as they are not typically used to deliver unauthenticated SMTP email
+        #  to an Internet mail server. (Spamhaus)
+        "DY-001" => ["550", "blocked"],
+
+        #  Mail rejected by Outlook.com for policy reasons. The likely cause is a compromised or
+        #  virus infected server/personal computer.
+        "DY-002" => ["550", "virusdetected"],
+
+        #  Mail rejected by Outlook.com for policy reasons. If you are not an email/network admin
+        #  please contact your Email/Internet Service Provider for help. For more information
+        #  about this block and to request removal please go to: Spamhaus.
+        "OU-001" => ["550", "blocked"],
+
+        #  Mail rejected by Outlook.com for policy reasons. Reasons for rejection may be related
+        #  to content with spam-like characteristics or IP/domain reputation.
+        "OU-002" => ["550", "badreputation"],
+    };
 
     my $statuscode = $argvs->{'deliverystatus'};
     my $thirddigit = int [split /[.]/, $statuscode]->[-1];
     my $issuedcode = lc $argvs->{'diagnosticcode'};
-    my $reasontext = '';
 
-    REASON: for my $e ( keys %$messagesof ) {
+    for my $e ( keys %$messagesof ) {
         # Each key is a reason name
         for my $f ( $messagesof->{ $e }->@* ) {
             # ["status-code", min, max, "error message"]
@@ -765,13 +821,16 @@ sub find {
                 next if $thirddigit < $f->[1]; 
                 next if $thirddigit > $f->[2]; 
             }
-
-            next unless index($issuedcode, $f->[3]) > -1;
-            $reasontext = $e;
-            last REASON;
+            return $e if index($issuedcode, $f->[3]) > -1;
         }
     }
-    return $reasontext;
+    for my $e ( keys %$errorcodes ) {
+        # The key name is an error code described at Outlook.com Postmaster/Troubleshooting
+        # https://substrate.office.com/ip-domain-management-snds/postmaster/troubleshooting
+        next if index($argvs->{'diagnosticcode'}, $e) < 0;
+        return $errorcodes->{ $e }->[1] if $argvs->{'replycode'} eq $errorcodes->{ $e }->[0];
+    }
+    return "";
 }
 
 1;
